==============
**randMAG**
==============

- Eric Hugoson (eric@hugoson.org / hugoson@evolbio.mpg.de / @EricHugo)

Produces randomised MAGs based on whole genomes provided and distribution of contig lengths given.